@@ -7,7 +7,7 @@ from arkitekt.cli.dev.autostage import watch_directory_and_stage
 import asyncio
 
 
-def dev(path, silent=False):
+def dev(path, silent=False, token=None, endpoint=None):
     """Run the app
 
     Args:
@@ -37,9 +37,8 @@ def dev(path, silent=False):
     if not silent:
         console.print(f"Loading manifest")
 
-    manifest = load_manifest(app_directory)
-    credentials = load_credentials(app_directory)
+    if not token or not endpoint:
+        credentials = load_credentials(app_directory)
+        endpoint, token = next(iter(credentials.items()))
 
-    endpoint, token = next(iter(credentials.items()))
-    print(endpoint, token)
     asyncio.run(watch_directory_and_stage(path, token=token, endpoint=endpoint))
