@@ -22,6 +22,7 @@ from arkitekt.cli.logic.initialize import initialize_manifest
 from arkitekt.cli.logic.connect import connect
 from arkitekt.cli.logic.run import run
 from arkitekt.cli.logic.dev import dev
+from arkitekt.cli.logic.build import build
 import yaml
 
 
@@ -42,6 +43,7 @@ class ArkitektOptions(str, Enum):
     WAIT = "wait"
     DEV = "dev"
     DUMP = "dump"
+    BUILD = "build"
 
 
 class TemplateOptions(str, Enum):
@@ -113,6 +115,7 @@ def main(
     endpoint_url=None,
     retries=3,
     interval=1,
+    tag=None,
     grant=GrantOptions.DEVICE,
 ):
 
@@ -140,11 +143,15 @@ def main(
             return
 
         if script == ArkitektOptions.RUN:
-            run(path=path, silent=silent)
+            run(path=path, silent=silent, token=token, endpoint=endpoint_url)
             return
 
         if script == ArkitektOptions.DEV:
-            dev(path=path, silent=silent)
+            dev(path=path, silent=silent, token=token, endpoint=endpoint_url)
+            return
+
+        if script == ArkitektOptions.BUILD:
+            build(path=path, silent=silent, tag=tag)
             return
 
         if script == ArkitektOptions.WAIT:
@@ -414,6 +421,9 @@ def entrypoint():
     parser.add_argument(
         "--retries", type=int, help="The Name of this script", default=0
     )
+    parser.add_argument(
+        "-t", type=str, help="The tag of the dockercontainer", default=None
+    )
     parser.add_argument(
         "--interval", type=int, help="The Name of this script", default=5
     )
@@ -459,6 +469,7 @@ def entrypoint():
         services=args.services.split(",") if args.services else [],
         silent=args.silent,
         token=args.token,
+        tag=args.t,
         endpoint_url=args.endpoint_url,
         grant=args.grant,
         retries=args.retries,
